@@ -1,4 +1,4 @@
-MC_USER=`id | sed 's/[^(]*(//;s/).*//'`
+MC_USER=`whoami`
 MC_PWD_FILE="${TMPDIR-/tmp}/mc-$MC_USER/mc.pwd.$$"
 /usr/local/bin/mc -P "$MC_PWD_FILE" "$@"
 
